@@ -28,7 +28,7 @@ def HelperMethod(requestClass=None, responseClass=None) :
                 args = FlaskManager.getArgsWithResponseClassInstanceAppended(args, responseClass)
                 methodReturn = resourceInstanceMethod(*args,**kwargs)
             except Exception as exception :
-                FlaskManager.raiseAndPersistGlobalException(exception, resourceInstance, resourceInstanceMethod)
+                FlaskManager.raiseAndHandleGlobalException(exception, resourceInstance, resourceInstanceMethod)
             return methodReturn
         ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
         return innerResourceInstanceMethod
