@@ -111,7 +111,6 @@ def validateArgs(self, method, objectRequest, expecteObjectClass):
 
 @Function
 def handleLogErrorException(exception, resourceInstance, resourceInstanceMethod, context, apiInstance = None) :
-    apiInstance.repository.backupContext()
     try :
         exception = getGeneralGlobalException(exception, resourceInstance, resourceInstanceMethod, context, apiInstance = None)
         if ObjectHelper.isNone(apiInstance):
@@ -138,7 +137,6 @@ def handleLogErrorException(exception, resourceInstance, resourceInstanceMethod,
         apiInstance.resource.manager.exception.handleErrorLog(httpErrorLog)
     except Exception as errorLogException :
         log.warning(handleLogErrorException, f'Failed to handle {ErrorLog.ErrorLog.__name__}', exception=errorLogException)
-    apiInstance.repository.reloadContextFromBackup()
     return exception
 
 
